@@ -2,34 +2,34 @@
 ##
 .defaultPotentialList <- function(rip.order, universe){
   cli     <- rip.order$cliques
-  potlist <- as.list(rep(NA,length(cli)))
+  APlist <- as.list(rep(NA,length(cli)))
   for (ii in 1:length(cli))
     {
       cc    <- cli[[ii]]
       vlab  <- universe$levels[cc]
-      potlist[[ii]] <- ptable(cc, vlab)
+      APlist[[ii]] <- parray(cc, vlab)
     }
-  potlist
+  APlist
 }
 
 ## Create potential list (cliques, gmData)
 ##
 .createPotentialList <- function(rip, gmd){
   cli     <- rip$cliques
-  potlist <- as.list(rep(NA,length(cli)))
+  APlist <- as.list(rep(NA,length(cli)))
   for (ii in 1:length(cli))
     {
       cc    <- cli[[ii]]
       vlab  <- valueLabels(gmd)[cc]
-      potlist[[ii]] <- ptable(cc, vlab)
+      APlist[[ii]] <- parray(cc, vlab)
     }
-  potlist
+  APlist
 }
 
 
-## Insert cpt's into potential list (cptlist, potlist)
+## Insert cpt's into potential list (cptlist, APlist)
 ##
-.insertCpt <- function(cptlist, potlist, rip, details=0){
+.insertCpt <- function(cptlist, APlist, rip, details=0){
   if (details>=1) cat(".Inserting cpt's in potential list [.insertCpt]\n")
   
   cli    <- rip$cliques
@@ -43,11 +43,11 @@
       .infoPrint(details,2,cat("..Current cpt:",varNames(cptc),"\n"))
       jj <- which(rowSums(amat[,vert,drop=FALSE])==length(vert))[1] # Host clique
       
-      potlist[[jj]] <- tableOp(potlist[[jj]], cptc, "*")    
+      APlist[[jj]] <- tableOp(APlist[[jj]], cptc, "*")    
     }
   
-  .infoPrint(details, 4, {cat("....potlist (after insertion):\n"); print(potlist) })
-  potlist
+  .infoPrint(details, 4, {cat("....APlist (after insertion):\n"); print(APlist) })
+  APlist
 }
 
 
