@@ -18,19 +18,23 @@ querygrain.grain <- function(object, nodes=nodeNames(object), normalize=TRUE,
     return(invisible(NULL))
   
   if (!object$isCompiled){
-    #cat("Compiling (and propagating) model ...\n")
+    #cat("CHK: Compiling (and propagating) model ...\n")
     object <- compile(object, propagate=TRUE)
   } else {
     if (!object$isPropagated){
-      #cat("Propagating model...\n")
+      #cat("CHK: Propagating model...\n")
       object <- propagate(object)
     }
   }
 
+  #print(nodes)
+
   type = match.arg(type, choices=c("marginal","joint","conditional"))
+  #print(type)
   switch(type,
          "marginal"={
            ans <- nodeMarginal(object, nodes, details)
+           #print(ans)
            if (return=="data.frame")
              ans <- lapply(ans, as.data.frame.table)
          },
@@ -42,7 +46,7 @@ querygrain.grain <- function(object, nodes=nodeNames(object), normalize=TRUE,
          "conditional"={
            qobject <- querygrain(object, nodes, type="joint", return="data.frame")
            nst     <- nodeStates(object)[nodes]
-           ans     <- ptable(nodes, nst, values=qobject$Freq, normalize="first") ## BRIS
+           ans     <- parray(nodes, nst, values=qobject$Freq, normalize="first") ## BRIS
            
            if (return=="data.frame")
              ans <- as.data.frame.table(ans) ## BRIS
@@ -56,31 +60,32 @@ querygrain.grain <- function(object, nodes=nodeNames(object), normalize=TRUE,
 
 
 
-nodeJoint <- function(bn, set=NULL, normalize=TRUE,details=1){
+nodeJoint <- function(object, set=NULL, normalize=TRUE,details=1){
 
   if (is.null(set))
-    set <- bn$rip$nodes
+    set <- object$rip$nodes
 
-  cli  <- bn$rip$cliques
+  cli  <- object$rip$cliques
 
   idxb <- sapply(cli, function(d) subsetof(set, d))
   
   if (any(idxb)){
     .infoPrint(details,1, cat(".Calculating directly from clique\n"))
-    tab <- bn$potlist[[which(idxb)[1]]]
+    ## querygrain - nodeJoin: Calculations based on equilCQpot
+    tab <- object$equilCQpot[[which(idxb)[1]]]
     value <- tableMargin(tab, set)
     if (!normalize){
-      value$values <- value$values * pFinding(bn)
+      value$values <- value$values * pFinding(object)
     }
   } else {
-    vl    <- bn$universe$levels[set]
-    value <- ptable(names(vl),vl)
+    vl    <- object$universe$levels[set]
+    value <- parray(names(vl),vl)
     levs  <- as.data.frame.table(value)[,1:length(vl), drop=FALSE] ## BRIS
     levs2 <- do.call("cbind",lapply(levs, as.character))
     p <- sapply(1:nrow(levs2), function(i){
       #cat ("nodeJoint:","\n")
       #print(levs2[i,])
-      pFinding(setFinding(bn, nodes=set, states=levs2[i,]))
+      pFinding(setFinding(object, nodes=set, states=levs2[i,]))
     })
     if (normalize)
       p <- p / sum(p)
@@ -91,10 +96,12 @@ nodeJoint <- function(bn, set=NULL, normalize=TRUE,details=1){
 }  
 
 
-nodeMarginal <- function(x, set=NULL,details=1){
+nodeMarginal <- function(object, set=NULL,details=1){
 
-  potlist  <- x$potlist
-  rip      <- x$rip
+  #cat("CHK: nodeMarginal\n")
+  ## querygrain - nodeMarginal: Calculations based on equilCQpot
+  equilCQpot  <- object$equilCQpot
+  rip      <- object$rip
   netnodes <- rip$nodes
   
   if (is.null(set))
@@ -102,9 +109,13 @@ nodeMarginal <- function(x, set=NULL,details=1){
   else
     nodes  <- set
 
+  #print(nodes)
   nodes <- intersect(netnodes, nodes)
-  nodes <- setdiff(nodes, getFinding(x)$nodes)
+  #print(nodes)
+  nodes <- setdiff(nodes, getFinding(object)$nodes)
 
+
+  
   if (length(nodes)>0){
     cli    <- rip$cliques
     mtablist <- as.list(rep(NA, length(nodes)))
@@ -112,7 +123,8 @@ nodeMarginal <- function(x, set=NULL,details=1){
       cvert  <- nodes[i]
       idxall <- which(sapply(cli, function(x) subsetof(cvert,x)))
       idx    <- idxall[1]
-      cpot   <- potlist[[idx]]
+      ## querygrain - nodeMarginal: Calculations based on equilCQpot
+      cpot   <- equilCQpot[[idx]]
       ##print(cpot)
       mtab   <- tableMargin(cpot, cvert)
       mtab   <- mtab/sum(mtab)
@@ -123,12 +135,6 @@ nodeMarginal <- function(x, set=NULL,details=1){
   } 
 }
 
-## print.ctabnumeric <- function(x,...){
-##   cat(paste(attr(x,"varNames"),collapse=' '),"\n")
-##   print.default(c(x))
-##   invisible(x)
-## }
-
 
 
 
